#
# spec file for package python-checkdmarc
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-checkdmarc
Version:        5.3.1
Release:        1.2
Summary:        A Python module and command line parser for SPF and DMARC records
License:        Apache-2.0
URL:            https://domainaware.github.io/checkdmarc
Source:         https://files.pythonhosted.org/packages/source/c/checkdmarc/checkdmarc-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/domainaware/checkdmarc/master/tests.py
Patch0:         skip-network-tests.patch
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography
Requires:       python-dnspython >= 2.0.0
Requires:       python-expiringdict >= 1.1.4
Requires:       python-publicsuffixlist
Requires:       python-pyleri >= 1.3.2
Requires:       python-requests >= 2.25.0
Requires:       python-timeout-decorator >= 0.4.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module dnspython >= 2.0.0}
BuildRequires:  %{python_module expiringdict >= 1.1.4}
BuildRequires:  %{python_module publicsuffixlist}
BuildRequires:  %{python_module pyleri >= 1.3.2}
BuildRequires:  %{python_module requests >= 2.25.0}
BuildRequires:  %{python_module timeout-decorator >= 0.4.1}
# /SECTION
%python_subpackages

%description
A Python module and command line parser for SPF and DMARC records.

%prep
%setup -q -n checkdmarc-%{version}
cp %{SOURCE1} .
%patch -P 0 -p0

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/checkdmarc
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative checkdmarc

%postun
%python_uninstall_alternative checkdmarc

%check
%pyunittest -v tests.py

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/checkdmarc
%{python_sitelib}/checkdmarc
%{python_sitelib}/checkdmarc-%{version}.dist-info

%changelog
* Thu Feb 29 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.3.1:
  * Ignore UnicodeDecodeError exceptions when querying for TXT records
  * Check DNSSEC on MX hostnames
  * USE DNSSEC when requesting DNSKEY records
  * Do not require an RRSIG answer when querying for DNSKEY records
  * Pass in nameservers and timeout when running get_dnskey recursively
  * Properly cache DNSKEY answers
  * Fix exception handling for query_mta_sts_record
  * Check for TLSA records
  * Add support for parsing SMTP TLS Reporting (RFC8460) DNS records
  * Add missing import dns.dnssec
  * Always use the actual subdomain or domain provided
  * Include MTA-STS and BIMI results in CSV output
  * Added the include_tag_descriptions parameter to
    checkdmarc.bimi.check_bimi()
  * Added the exception class MTASTSPolicyDownloadError
  * Major refactoring: Change from a single module to a package of modules,
    with each checked standard as its own package
  * Add support for MTA-STS RFC 8461
  * Add support for BIMI
  * Specify a BIMI selector using the --bimi-selector/-b option
  * Fix SPF query error and warning messages
  * Add support for null MX records - RFC 7505
  * Make DMARC retorting URI error messages more clear
  * Fix compatibility with Python 3.8
  * SPFRecordNotFound exception now includes a domain argument
  * The DMARC missing authorization error message now includes the full
    expected DNS record
  * Properly parse DMARC and BIMI records for domains that do not have an
    identified base domain
  * Add ignore_unrelated_records argument to query_dmarc_record()
  * Replace publicsuffix2 with publicsuffixlist
  * Maintain the original character case of the DMARC record
  * Always treat tag names as lowercase
  * Always treat the DMARC v tag value as if it was uppercase
  * Always treat the DMARC p, and fo tag values as if they were lowercase
  * Always treat URI schemes as lowercase, but maintain the case of the address
  * Ignore case and whitespace when parsing DMARC and BIMI key=value pairs
  * Handle missing PTR records more gracefully
  * Redundant DMARC fo tag values now result in a warning
  * Detect non-trivial loops
  * Raise a SPFSyntaxError exception when an IP address and IP version do
    not match
  * Fix raising the DMARCRecordNotFound exception when a DMARC record does
    not exist
  * Add void lookup limit
  * Add Support for User Defined DNS Resolver Object
  * Fix DNS caching
  * Fix CSV output
  * Always parse RUA and RUF fields, even if other parts of the record are
    invalid
  * Migrate build from setuptools to hatch
- Stop shipping LICENSE, now included directly.
- Refresh tests.py from upstream.
- Switch to pyproject and patch macros.
- No more greedy globs in %%files.
- Drop skip-broken-tests.patch, not required.
- Add patch skip-network-tests.patch, skip tests that require network access.
* Wed Jul 21 2021 Matej Cepl <mcepl@suse.com>
- Use %%pyunittest macro instead of directly calling %%python_exec
* Tue Jul 20 2021 Martin Hauke <mardnh@gmx.de>
- Use tests.py from github
- Add patch:
  * skip-broken-tests.patch
* Sat Jul 17 2021 Martin Hauke <mardnh@gmx.de>
- Initial package, version 4.4.1
